
from .environment import get_environment, boolean_mapper

DEBUG = get_environment('DEBUG', mapper=boolean_mapper)

# make tests faster
SOUTH_TESTS_MIGRATE = False
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'test',
    }}


INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'common.apps.CommonConfig',
    'connections.apps.ConnectionsConfig',
    'examples.apps.ExamplesConfig',
    'meanings.apps.MeaningsConfig',
    'semantics.apps.SemanticsConfig',
    'syntax.apps.SyntaxConfig',
    'entries.apps.EntriesConfig',
    'phrase_expansions.apps.PhraseExpansionsConfig',
    'dictionary_statistics.apps.DictionaryStatisticsConfig',
    'download.apps.DownloadConfig',
    'users.apps.UsersConfig',
    'crispy_forms',
    'django_extensions',
    'unifier.apps.UnifierConfig',
    'financial_settlement.apps.FinStatementConfig',
    'freelus.apps.FreeLusConfig',
    'vertical_relations.apps.VerticalRelationsConfig',
]

SECRET_KEY = get_environment('SECRET_KEY')

ROOT_URLCONF = 'shellvalier.urls'


CRISPY_TEMPLATE_PACK = 'bootstrap4'
CRISPY_FAIL_SILENTLY = not DEBUG

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.locale.LocaleMiddleware',
]

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'shellvalier.wsgi.application'

