from django.db import models

from unifier.models import UnifiedFrame, UnifiedFrameArgument


class MainVerticalRelation(models.Model):
    name = models.CharField(max_length=100)
    priority = models.PositiveIntegerField()

    class Meta:
        ordering = ['priority']

    def __str__(self):
        return self.name


class TemporalVerticalRelation(models.Model):
    name = models.CharField(max_length=100)
    priority = models.PositiveIntegerField()

    class Meta:
        ordering = ['priority']

    def __str__(self):
        return self.name


class VerticalRelationNegation(models.Model):
    name = models.CharField(max_length=100)
    priority = models.PositiveIntegerField()

    class Meta:
        ordering = ['priority']

    def __str__(self):
        return self.name


class UnifiedFrameArgument2UnifiedFrameArgumentMapping(models.Model):
    source_unified_argument = models.ForeignKey(UnifiedFrameArgument, related_name='source_unified_argument_mapping',
                                                on_delete=models.PROTECT)
    target_unified_argument = models.ForeignKey(UnifiedFrameArgument, related_name='target_unified_argument_mapping',
                                                blank=True, null=True, on_delete=models.PROTECT)
    unified_frame_vertical_relation = models.ForeignKey('UnifiedFrameVerticalRelation',
                                                        related_name='unified_frame_arguments_mapping',
                                                        on_delete=models.PROTECT)


class UnifiedFrameVerticalRelation(models.Model):
    source_unified_frame = models.ForeignKey(UnifiedFrame, related_name='source_vertical_relation',
                                             default=None, blank=True, null=True, on_delete=models.PROTECT)
    target_unified_frame = models.ForeignKey(UnifiedFrame, related_name='target_vertical_relation',
                                             default=None, blank=True, null=True, on_delete=models.PROTECT)
    main_vertical_relation = models.ForeignKey(MainVerticalRelation, related_name='unified_frame_vertical_relation',
                                               default=None, blank=True, null=True, on_delete=models.PROTECT)
    temporal_vertical_relation = models.ManyToManyField(related_name='unified_frame_vertical_relation',
                                                        to=TemporalVerticalRelation)
    negation = models.ForeignKey(VerticalRelationNegation, related_name='vertical_relation_negation',
                                 default=None, blank=True, null=True, on_delete=models.PROTECT)
    negation_argument = models.ForeignKey(UnifiedFrameArgument, related_name='negation_argument',
                                          default=None, blank=True, null=True, on_delete=models.PROTECT)

    subrelation = models.ForeignKey('UnifiedFrameVerticalRelation', related_name='subrelation_recursive',
                                    default=None, blank=True, null=True, on_delete=models.PROTECT)
    temporal_vertical_relation_for_subrelation = models.ForeignKey(TemporalVerticalRelation,
                                                                   related_name='temporal_vertical_relation_for_subrelation',
                                                                   default=None, blank=True, null=True,
                                                                   on_delete=models.PROTECT)

    iter_temporal_vertical_relation = models.ForeignKey(TemporalVerticalRelation,
                                                        related_name='iter_temporal_vertical_relation',
                                                        default=None, blank=True, null=True, on_delete=models.PROTECT)

    def __str__(self):
        subtelation_temporal = self.temporal_vertical_relation_for_subrelation.name \
            if self.temporal_vertical_relation_for_subrelation else ''
        subrelation_str = (', sub: (iterated:' + self.subrelation.target_unified_frame.title +
                           ' - ' + subtelation_temporal + ')') \
            if self.subrelation and self.subrelation.target_unified_frame else ''

        target_title = self.target_unified_frame.title if self.target_unified_frame else ''
        temporal_relations = ','.join(
            [str(t) for t in self.temporal_vertical_relation.all()]) if self.temporal_vertical_relation else ''
        negation = ' (' + self.negation.name + ': ' + self.negation_argument.role.role.role + ')' \
            if self.negation else ''
        iteration = ' (iterated:' + str(
            self.iter_temporal_vertical_relation.name) + '] ' if self.iter_temporal_vertical_relation else ''
        return '{0}::{1}:{2} - {3}, {4}{5}{6}{7}'.format(str(self.id), self.source_unified_frame.title, target_title,
                                                         self.main_vertical_relation.name, temporal_relations, negation,
                                                         iteration, subrelation_str)
